=== modified file 'NEWS'
--- NEWS	2011-03-15 23:05:04 +0000
+++ NEWS	2011-03-23 09:49:44 +0000
@@ -6,6 +6,14 @@
 
   * Show avatars for committers and authors in "bzr viz". (Guillaume Hain)
 
+  * gannotate now supports interactive substring search in the file content.
+    interactive search for line numbers has been removed, use Ctrl-G instead.
+    (Sergei Golubchik)
+
+  * visualise now supports interactive changeset comment search.
+    interactive search for revision numbers continues to work.
+    (Sergei Golubchik)
+
 0.100.0	2011-03-02
 
  BUG FIXES

=== modified file 'annotate/gannotate.py'
--- annotate/gannotate.py	2011-03-14 20:12:19 +0000
+++ annotate/gannotate.py	2011-03-23 09:49:44 +0000
@@ -318,9 +318,12 @@
         col.add_attribute(cell, "text", TEXT_LINE_COL)
         tv.append_column(col)
 
-        # FIXME: Now that C-f is now used for search by text we
-        # may as well disable the auto search.
-        tv.set_search_column(LINE_NUM_COL)
+        # interactive substring search
+        def search_equal_func(model, column, key, iter):
+            return model.get_value(iter, TEXT_LINE_COL).lower().find(key.lower()) == -1
+
+        tv.set_enable_search(True)
+        tv.set_search_equal_func(search_equal_func)
 
         return tv
 

=== modified file 'branchview/treeview.py'
--- branchview/treeview.py	2011-03-14 20:12:19 +0000
+++ branchview/treeview.py	2011-03-23 09:49:44 +0000
@@ -334,7 +334,18 @@
         self.treeview = gtk.TreeView()
 
         self.treeview.set_rules_hint(True)
-        self.treeview.set_search_column(treemodel.REVNO)
+        # combined revno/summary interactive search
+        #
+        # the row in a treemodel is considered "matched" if a REVNO *starts*
+        # from the key (that is the key is found in a REVNO at the offset 0)
+        # or if a MESSAGE *contains* the key anywhere (that is, the key is
+        # found case insensitively in a MESSAGE at any offset)
+        def search_equal_func(model, column, key, iter):
+            return (model.get_value(iter, treemodel.REVNO).find(key) != 0
+                and model.get_value(iter, treemodel.MESSAGE).lower().find(key.lower()) == -1)
+
+        self.treeview.set_search_equal_func(search_equal_func)
+        self.treeview.set_enable_search(True)
 
         # Fix old PyGTK bug - by JAM
         set_tooltip = getattr(self.treeview, 'set_tooltip_column', None)

